@@ -20,10 +20,10 @@
 
 import weakref
 import time
-import pytz
 import datetime
 import threading
 import numpy
+import sys
 
 
 #: (:mod:`PNIWriter` or :mod:`H5PYWriter`or :mod:`H5CppWriter`)
@@ -34,6 +34,13 @@ writer = None
 writerlock = threading.Lock()
 
 
+try:
+    _npver = numpy.version.version.split(".")
+    NPMAJOR = int(_npver[0])
+except Exception:
+    NPMAJOR = 1
+
+
 def open_file(filename, readonly=False, **pars):
     """ open the new file
 
@@ -298,13 +305,13 @@ class FTHyperslab(object):
         """ constructor
 
         :param offset: a list of offsets
-        :type offset: :tuple:`int`
+        :type offset: :obj:`tuple` <:obj:`int`>
         :param block: a list of blocks
-        :type block: :tuple:`int`
+        :type block: :obj:`tuple` <:obj:`int`>
         :param count: a list of counts
-        :type count: :tuple:`int`
+        :type count: :obj:`tuple` <:obj:`int`>
         :param stride: a list of strides
-        :type stride: :tuple:`int`
+        :type stride: :obj:`tuple` <:obj:`int`>
         """
         self.offset = offset
         self.block = block
@@ -447,7 +454,14 @@ def first(array):
         if isinstance(array, numpy.ndarray) and len(array) == 1:
             return array[0]
     except Exception:
-        pass
+        try:
+            if hasattr(array, "all"):
+                if NPMAJOR < 2:
+                    array = array.all()
+                if hasattr(array, "decode"):
+                    return array.decode()
+        except Exception:
+            pass
     return array
 
 
@@ -521,13 +535,22 @@ class FTFile(FTObject):
         :rtype: :obj:`str`
         """
         tzone = time.tzname[0]
+        if tzone in ['CET', 'CEST']:
+            tzone = 'Europe/Berlin'
+        fmt = '%Y-%m-%dT%H:%M:%S.%f%z'
         try:
-            tz = pytz.timezone(tzone)
+            if sys.version_info >= (3, 9):
+                import zoneinfo
+                tz = zoneinfo.ZoneInfo(tzone)
+                starttime = datetime.datetime.now().replace(tzinfo=tz)
+            else:
+                import pytz
+                tz = pytz.timezone(tzone)
+                starttime = tz.localize(datetime.datetime.now())
         except Exception:
             import tzlocal
             tz = tzlocal.get_localzone()
-        fmt = '%Y-%m-%dT%H:%M:%S.%f%z'
-        starttime = tz.localize(datetime.datetime.now())
+            starttime = datetime.datetime.now().replace(tzinfo=tz)
         return str(starttime.strftime(fmt))
 
     def default_field(self):
@@ -653,34 +676,61 @@ class FTGroup(FTObject):
         """
         FTObject._reopen(self)
 
-    def default_field(self, signals=None):
+    def default_field(self, signals=None, nexuspath=None):
         """ field pointed by default attributes
 
+        :type signals: :obj:`list`<:obj:`str`>
+        :param axes: axes names
+        :param entryname: base nexus path to be opened
+        :type entryname: :obj:`str`
         :returns: field pointed by default attributes
         :rtype: :class:`FTField`
         """
+
         node = self
         searching = True
+        nexuspath = nexuspath or ""
+        groups = [n for n in nexuspath.split("/") if n]
         while searching:
-            attrs = node.attributes
-            if hasattr(node, "names") and "default" in attrs.names():
-                nname = attrs["default"].read()
-                if isinstance(nname, numpy.ndarray) and len(nname):
-                    nname = nname[0]
-                if nname in node.names():
-                    node = node.open(nname)
+            nname = None
+            if hasattr(node, "names"):
+                gname = ""
+                if groups:
+                    gname = groups.pop(0)
+                if gname in node.names():
+                    node = node.open(gname)
                     continue
+                else:
+                    groups = []
+                attrs = node.attributes
+                if "default" in attrs.names():
+                    nname = attrs["default"].read()
+                    if isinstance(nname, numpy.ndarray) and len(nname):
+                        nname = nname[0]
+                    if nname in node.names():
+                        node = node.open(nname)
+                        continue
             searching = False
-        if hasattr(node, "names"):
-            attrs = node.attributes
-            if "signal" in attrs.names():
-                nname = attrs["signal"].read()
-                if isinstance(nname, numpy.ndarray) and len(nname):
-                    nname = nname[0]
-                if nname in node.names():
-                    node = node.open(nname)
         if not hasattr(node, "names"):
             return node
+        if hasattr(node, "names"):
+            if groups:
+                gname = groups.pop(0)
+            if gname in node.names():
+                node = node.open(gname)
+                if not hasattr(node, "names"):
+                    return node
+            else:
+                groups = []
+                attrs = node.attributes
+                if "signal" in attrs.names():
+                    nname = attrs["signal"].read()
+                    if isinstance(nname, numpy.ndarray) and len(nname):
+                        nname = nname[0]
+                    if nname in node.names():
+                        node = node.open(nname)
+                    if not hasattr(node, "names"):
+                        return node
 
         for cnm in ["NXentry", "NXdata", "NXmonitor", "NXlog"]:
             names = node.names()
@@ -936,9 +986,49 @@ class FTDataFilter(FTObject):
         #: (:obj:`int`) compression rate
         self._rate = 0
         #: (:obj:`int`) compression filter id
-        self._filterid = 1
+        self._filterid = 0
         #: (:obj:`tuple` <:obj:`int`>) compression options
         self._options = tuple()
+        #: (:obj:`str`) filter name
+        self._name = ""
+        #: (:obj:`str`) filter availability
+        self._availability = ""
+
+    @property
+    def name(self):
+        """ getter for filter name
+
+        :returns: filter name
+        :rtype: :obj:`tuple` <:obj:`str`>
+        """
+        return self._name
+
+    @name.setter
+    def name(self, value):
+        """ setter for filter name
+
+        :param value: filter name
+        :type value: :obj:`tuple` <:obj:`str`>
+        """
+        self._name = value
+
+    @property
+    def availability(self):
+        """ getter for filter availability
+
+        :returns: filter availability
+        :rtype: :obj:`tuple` <:obj:`str`>
+        """
+        return self._availability
+
+    @availability.setter
+    def availability(self, value):
+        """ setter for filter availability
+
+        :param value: filter availability
+        :type value: :obj:`tuple` <:obj:`str`>
+        """
+        self._availability = value
 
     @property
     def options(self):
@@ -1114,7 +1204,7 @@ class FTAttribute(FTObject):
         """ write attribute value
 
         :param t: slice tuple
-        :type t: :obj:`tuple`
+        :type t: :obj:`tuple` <:obj:`int`>
         :param o: python object
         :type o: :obj:`any`
         """
@@ -1123,7 +1213,7 @@ class FTAttribute(FTObject):
         """ read attribute value
 
         :param t: slice tuple
-        :type t: :obj:`tuple`
+        :type t: :obj:`tuple` <:obj:`int`>
         :returns: python object
         :rtype: :obj:`any`
         """
