@@ -108,6 +108,20 @@ moduleAttributes = {
     'xmcd': ['Value', None],
 }
 
+#: attributes of device modules to acquire with elements:
+#  'module': {<device_parts[4]>, <tango_attr>}
+moduleAttributeMap = {
+    'amptekroi': {
+        '1': 'CountsRoI1',
+        '2': 'CountsRoI2',
+        '3': 'CountsRoI3',
+        '4': 'CountsRoI4',
+        '5': 'CountsRoI5',
+        '6': 'CountsRoI6',
+        '7': 'CountsRoI7',
+        '8': 'CountsRoI8',
+    },
+}
 
 #: (:obj:`list` <:obj:`str`>) modules of 2d detectors
 twoDModules = [
@@ -242,12 +256,12 @@ def openServer(device):
 
     while not found and cnt < 1000:
         if cnt > 1:
-            time.sleep(0.01)
+            time.sleep(0.02)
         try:
             if cnfServer.state() != tango.DevState.RUNNING:
                 found = True
         except tango.DevFailed:
-            time.sleep(0.01)
+            time.sleep(0.02)
             found = False
         cnt += 1
 
@@ -410,7 +424,7 @@ def _remoteCall(server, func, *args, **kwargs):
     :param args: function list arguments
     :type args: :obj:`list` <`and`>
     :param kwargs: function dict arguments
-    :type args: :obj:`dict` <:obj:`str` , `any`>
+    :type kwargs: :obj:`dict` <:obj:`str` , `any`>
     :returns: function result
     :rtype: `any`
     """
