@@ -134,6 +134,25 @@ standardComponentVariables = {
             'doc': "secop timeout (string)"
         },
     },
+    'secoplinks': {
+        'meanings': {
+            'default': "temperature,magnetic_field,electric_field,"
+            "stress_field,pressure",
+            'doc': "secop meanings link lists MANDATORY (string)"
+        },
+        'environments': {
+            'default': "temperature,magnetic_field",
+            'doc': "secop environment link lists MANDATORY (string)"
+        },
+        'samplename': {
+            'default': 'sample',
+            'doc': "sample group name (string)"
+        },
+        'sampleenvname': {
+            'default': 'sample_environment',
+            'doc': "sample environment group name (string)"
+        },
+    },
     'groupsecop': {
         'host': {
             'default': None,
@@ -946,6 +965,14 @@ standardComponentVariables = {
             'default': 'source',
             'doc': "source group name (string)"
         },
+        'type': {
+            'default': 'Synchrotron X-ray Source',
+            'doc': "source type (string)"
+        },
+        'probe': {
+            'default': 'x-ray',
+            'doc': "source probe (string)"
+        },
     },
     'datasignal': {
         'signal': {
@@ -1028,6 +1055,10 @@ standardComponentVariables = {
             'default': "10000",
             'doc': "tango port (string)"
         },
+        'defaultattrs': {
+            'default': "False",
+            'doc': "add default attributes (string)"
+        },
 
     },
     'descriptiontext': {
@@ -1087,6 +1118,14 @@ standardComponentVariables = {
             'default': 'source',
             'doc': "source group name (string)"
         },
+        'type': {
+            'default': 'Synchrotron X-ray Source',
+            'doc': "source type (string)"
+        },
+        'probe': {
+            'default': 'x-ray',
+            'doc': "source probe (string)"
+        },
     },
     'defaultsample': {
     },
@@ -1523,16 +1562,28 @@ standardComponentTemplateFiles = {
         'secop.ds.xml',
         'secop_time.ds.xml',
         'client_start_time.ds.xml',
+        'sample_env_links.ds.xml',
+        'sample_log_links.ds.xml',
+    ],
+    'secoplinks': [
+        'sample_env_links.ds.xml',
+        'sample_log_links.ds.xml',
+        'sample_nxdata.ds.xml',
+        'sampleenv_nxdata.ds.xml',
     ],
     'singlesecop': [
         'singlesecop.ds.xml',
         'singlesecop_time.ds.xml',
         'client_start_time.ds.xml',
+        'sample_env_links.ds.xml',
+        'sample_log_links.ds.xml',
     ],
     'groupsecop': [
         'groupsecop.ds.xml',
         'groupsecop_time.ds.xml',
         'client_start_time.ds.xml',
+        'sample_env_links.ds.xml',
+        'sample_log_links.ds.xml',
     ],
     'slit': ['slit.xml'],
     'source': ['source.xml'],
@@ -1706,6 +1757,10 @@ moduleTemplateFiles = {
     'mythen': ['mythen.xml',
                'mythen_postrun.ds.xml',
                'mythen_filestartnumber.ds.xml'],
+    'pilc': ['pilc.xml',
+             'pilc_triggermode_cb.ds.xml'],
+    'pilctimeid': ['pilctimeid.xml',
+                   'pilctimeid_triggermode_cb.ds.xml'],
     'pilatus100k': ['pilatus.xml',
                     'pilatus_postrun.ds.xml',
                     'pilatus100k_description.ds.xml',
@@ -1742,6 +1797,12 @@ moduleTemplateFiles = {
                 'limaccd_ypixelsize.ds.xml',
                 'limaccd_description.ds.xml',
                 'limaccd_filestartnum_cb.ds.xml'],
+    'limaccdvds': ['limaccdvds.xml',
+                   'limaccdvds_postrun.ds.xml',
+                   'limaccdvds_xpixelsize.ds.xml',
+                   'limaccdvds_ypixelsize.ds.xml',
+                   'limaccdvds_description.ds.xml',
+                   'limaccdvds_filestartnum_cb.ds.xml'],
     'limaccds': ['limaccd.xml',
                  'limaccd_postrun.ds.xml',
                  'limaccd_xpixelsize.ds.xml',
@@ -1813,12 +1874,74 @@ moduleTemplateFiles = {
     'mca_xia': [
         'mcaxia.xml'
     ],
+    'xspress3': [
+        'xspress3.xml',
+        'xspress3_triggermode_cb.ds.xml'
+    ],
+    'minipix': [
+        'minipix.xml',
+        'minipix_nxdata.ds.xml',
+        'minipix_description.ds.xml',
+        'minipix_triggermode_cb.ds.xml',
+        'minipix_framenumbers_cb.ds.xml',
+        'minipix_savefilename_cb.ds.xml'
+    ],
     'eigerdectris': [
         'eigerdectris.xml',
         'eigerdectris_stepindex.ds.xml',
+        'eigerdectris_nbimages_cb.ds.xml',
         'eigerdectris_description_cb.ds.xml',
         'eigerdectris_triggermode_cb.ds.xml'
     ],
+    'eigerdectrismesh': [
+        'eigerdectrismesh.xml',
+        'eigerdectrismesh_stepindex.ds.xml',
+        'eigerdectrismesh_nbimages_cb.ds.xml',
+        'eigerdectrismesh_description_cb.ds.xml',
+        'eigerdectrismesh_triggermode_cb.ds.xml'
+    ],
+    'eiger1m16vds': [
+        'eiger1m16vds.xml',
+        'eiger1m16vds_stepindex.ds.xml',
+        'eiger1m16vds_nbimages_cb.ds.xml',
+        'eiger1m16vds_description_cb.ds.xml',
+        'eiger1m16vds_triggermode_cb.ds.xml'
+    ],
+    'eiger4m16vds': [
+        'eiger4m16vds.xml',
+        'eiger4m16vds_stepindex.ds.xml',
+        'eiger4m16vds_nbimages_cb.ds.xml',
+        'eiger4m16vds_description_cb.ds.xml',
+        'eiger4m16vds_triggermode_cb.ds.xml'
+    ],
+    'eiger9m16vds': [
+        'eiger9m16vds.xml',
+        'eiger9m16vds_stepindex.ds.xml',
+        'eiger9m16vds_nbimages_cb.ds.xml',
+        'eiger9m16vds_description_cb.ds.xml',
+        'eiger9m16vds_triggermode_cb.ds.xml'
+    ],
+    'eiger1m32vds': [
+        'eiger1m32vds.xml',
+        'eiger1m32vds_stepindex.ds.xml',
+        'eiger1m32vds_nbimages_cb.ds.xml',
+        'eiger1m32vds_description_cb.ds.xml',
+        'eiger1m32vds_triggermode_cb.ds.xml'
+    ],
+    'eiger4m32vds': [
+        'eiger4m32vds.xml',
+        'eiger4m32vds_stepindex.ds.xml',
+        'eiger4m32vds_nbimages_cb.ds.xml',
+        'eiger4m32vds_description_cb.ds.xml',
+        'eiger4m32vds_triggermode_cb.ds.xml'
+    ],
+    'eiger9m32vds': [
+        'eiger9m32vds.xml',
+        'eiger9m32vds_stepindex.ds.xml',
+        'eiger9m32vds_nbimages_cb.ds.xml',
+        'eiger9m32vds_description_cb.ds.xml',
+        'eiger9m32vds_triggermode_cb.ds.xml'
+    ],
 }
 
 #: (:obj:`dict` <:obj:`str` , :obj:`list` <:obj:`str`> >)
@@ -1833,6 +1956,7 @@ moduleMultiAttributes = {
     'limaccd': [
         'camera_type', 'camera_pixelsize', 'camera_model',
         'acq_mode', 'acq_nb_frames', 'acq_trigger_mode',
+        'acq_expo_time',
         'last_image_saved',
         'latency_time',  'acc_max_expo_time',
         'acc_expo_time', 'acc_time_mode',
@@ -1843,6 +1967,34 @@ moduleMultiAttributes = {
         'saving_suffix',
         'saving_next_number',
         'saving_format',
+        'saving_index_format',
+        'saving_frame_per_file',
+        'image_type',
+        'image_width',
+        'image_height',
+        'image_sizes',
+        'image_roi',
+        'image_bin',
+        'image_flip',
+        'image_rotation',
+        'shutter_mode',
+        'shutter_open_time',
+    ],
+    'limaccdvds': [
+        'camera_type', 'camera_pixelsize', 'camera_model',
+        'acq_mode', 'acq_nb_frames', 'acq_trigger_mode',
+        'acq_expo_time',
+        'last_image_saved',
+        'latency_time',  'acc_max_expo_time',
+        'acc_expo_time', 'acc_time_mode',
+        'acc_dead_time', 'acc_live_time',
+        'saving_mode',
+        'saving_directory',
+        'saving_prefix',
+        'saving_suffix',
+        'saving_next_number',
+        'saving_format',
+        'saving_index_format',
         'saving_frame_per_file',
         'image_type',
         'image_width',
@@ -1868,6 +2020,7 @@ moduleMultiAttributes = {
         'saving_suffix',
         'saving_next_number',
         'saving_format',
+        'saving_index_format',
         'saving_frame_per_file',
         'image_type',
         'image_width',
@@ -1916,6 +2069,46 @@ moduleMultiAttributes = {
                        'ThrottleEnable'],
     'maiainterlock': ['BiasPeltierInterlock', 'BiasPeltierInterlockUptime',
                       'Pressure'],
+    'pilc': [
+        'PositionTriggerStart', 'PositionTriggerStepSize',
+        'PositionTriggerStop',
+        'NbTriggers', 'TriggerPulseLength', 'Arm', 'TriggerMode',
+        'TimeTriggerStart', 'TimeTriggerStepSize',
+        'FilePrefix', 'FileDir', 'FileName',
+        'TriggerCounter', 'EncoderTrigger', 'RemainingTriggers',
+        'EncoderTriggering', 'BufferLoad',
+        'Position1Conversion', 'Position2Conversion', 'Position3Conversion',
+        'Position4Conversion', 'Position5Conversion',
+        'CurrentPosition1', 'CurrentPosition2', 'CurrentPosition3',
+        'CurrentPosition4', 'CurrentPosition5', 'MaskDataToWrite',
+        'Metadata1', 'Metadata2', 'Metadata3', 'Metadata4', 'Metadata5',
+        'TriggersPerFile', 'SoftwareInhibit', 'HardwareInhibit',
+        'CounterConfig',
+        # 'CounterData',
+        # 'Encoder1Data', 'Position1Data',
+        # 'Encoder2Data', 'Encoder3Data', 'Encoder4Data', 'Encoder5Data',
+        # 'Position2Data', 'Position3Data', 'Position4Data', 'Position5Data'
+    ],
+    'pilctimeid': [
+        'PositionTriggerStart', 'PositionTriggerStepSize',
+        'PositionTriggerStop',
+        'NbTriggers', 'TriggerPulseLength', 'Arm', 'TriggerMode',
+        'TimeTriggerStart', 'TimeTriggerStepSize',
+        'FilePrefix', 'FileDir', 'FileName',
+        'TriggerCounter', 'EncoderTrigger', 'RemainingTriggers',
+        'EncoderTriggering', 'BufferLoad',
+        'Position1Conversion', 'Position2Conversion', 'Position3Conversion',
+        'Position4Conversion', 'Position5Conversion',
+        'CurrentPosition1', 'CurrentPosition2', 'CurrentPosition3',
+        'CurrentPosition4', 'CurrentPosition5', 'MaskDataToWrite',
+        'Metadata1', 'Metadata2', 'Metadata3', 'Metadata4', 'Metadata5',
+        'TriggersPerFile', 'SoftwareInhibit', 'HardwareInhibit',
+        'CounterConfig',
+        # 'CounterData',
+        # 'Encoder1Data', 'Position1Data',
+        # 'Encoder2Data', 'Encoder3Data', 'Encoder4Data', 'Encoder5Data',
+        # 'Position2Data', 'Position3Data', 'Position4Data', 'Position5Data'
+    ],
     'pilatus100k': [
         'DelayTime', 'ExposurePeriod', 'ExposureTime', 'FileDir',
         'FilePostfix', 'FilePrefix', 'FileStartNum', 'LastImageTaken',
@@ -2022,12 +2215,76 @@ moduleMultiAttributes = {
     ],
     'marccd': [
         'FrameShift', 'SavingDirectory', 'SavingPostfix', 'SavingPrefix'],
+    'xspress3': [
+        'Compression', 'ExposureTime', 'FileDir', 'FilePrefix',
+        'FramesPerFile',
+        'MaskDataToWrite', 'MCALength', 'NbFrames', 'RingBuffer', 'RunMode',
+        'SaveBufferOnStop', 'SaveData', 'TriggerMode',
+        'LastFrame', 'LastFrameWritten', 'LastLiveFrame',
+        'BufferUsage', 'BufferUsageWriter',
+        # DataCh00,
+        # DataCh00ROI0, DataCh00ROI0End, DataCh00ROI0Start,
+        # DataCh00ROI1, DataCh00ROI1End, DataCh00ROI1Start,
+        # DataCh01,
+        # DataCh01ROI0, DataCh01ROI0End, DataCh01ROI0Start,
+        # DataCh01ROI1, DataCh01ROI1End, DataCh01ROI1Start,
+    ],
+    'minipix': [
+        'EnergyThreshold', 'TriggerMode', 'FrameNumbers',
+        'SaveAllImages', 'Width', 'Height', 'ConfigFilePath',
+        'FilePostfix', 'FilePrefix', 'SaveFilePath',
+        "FramesPerFile", 'SaveFileName', 'FileStartNum',
+        'AppendData', 'BiasVoltage', 'FrameCounter',
+        'FrameTime', 'LiveImage', 'OpMode',
+    ],
     'eigerdectris': [
         'TriggerMode', 'NbTriggers', 'Description', 'NbImages', 'BitDepth',
         'ReadoutTime', 'CountTime', 'EnergyThreshold', 'FrameTime',
         'RateCorrectionEnabled', 'FlatFieldEnabled', 'Temperature',
         'AutoSummationEnabled', 'Humidity', 'PhotonEnergy', 'Wavelength',
     ],
+    'eigerdectrismesh': [
+        'TriggerMode', 'NbTriggers', 'Description', 'NbImages', 'BitDepth',
+        'ReadoutTime', 'CountTime', 'EnergyThreshold', 'FrameTime',
+        'RateCorrectionEnabled', 'FlatFieldEnabled', 'Temperature',
+        'AutoSummationEnabled', 'Humidity', 'PhotonEnergy', 'Wavelength',
+    ],
+    'eiger1m16vds': [
+        'TriggerMode', 'NbTriggers', 'Description', 'NbImages', 'BitDepth',
+        'ReadoutTime', 'CountTime', 'EnergyThreshold', 'FrameTime',
+        'RateCorrectionEnabled', 'FlatFieldEnabled', 'Temperature',
+        'AutoSummationEnabled', 'Humidity', 'PhotonEnergy', 'Wavelength',
+    ],
+    'eiger4m16vds': [
+        'TriggerMode', 'NbTriggers', 'Description', 'NbImages', 'BitDepth',
+        'ReadoutTime', 'CountTime', 'EnergyThreshold', 'FrameTime',
+        'RateCorrectionEnabled', 'FlatFieldEnabled', 'Temperature',
+        'AutoSummationEnabled', 'Humidity', 'PhotonEnergy', 'Wavelength',
+    ],
+    'eiger9m16vds': [
+        'TriggerMode', 'NbTriggers', 'Description', 'NbImages', 'BitDepth',
+        'ReadoutTime', 'CountTime', 'EnergyThreshold', 'FrameTime',
+        'RateCorrectionEnabled', 'FlatFieldEnabled', 'Temperature',
+        'AutoSummationEnabled', 'Humidity', 'PhotonEnergy', 'Wavelength',
+    ],
+    'eiger1m32vds': [
+        'TriggerMode', 'NbTriggers', 'Description', 'NbImages', 'BitDepth',
+        'ReadoutTime', 'CountTime', 'EnergyThreshold', 'FrameTime',
+        'RateCorrectionEnabled', 'FlatFieldEnabled', 'Temperature',
+        'AutoSummationEnabled', 'Humidity', 'PhotonEnergy', 'Wavelength',
+    ],
+    'eiger4m32vds': [
+        'TriggerMode', 'NbTriggers', 'Description', 'NbImages', 'BitDepth',
+        'ReadoutTime', 'CountTime', 'EnergyThreshold', 'FrameTime',
+        'RateCorrectionEnabled', 'FlatFieldEnabled', 'Temperature',
+        'AutoSummationEnabled', 'Humidity', 'PhotonEnergy', 'Wavelength',
+    ],
+    'eiger9m32vds': [
+        'TriggerMode', 'NbTriggers', 'Description', 'NbImages', 'BitDepth',
+        'ReadoutTime', 'CountTime', 'EnergyThreshold', 'FrameTime',
+        'RateCorrectionEnabled', 'FlatFieldEnabled', 'Temperature',
+        'AutoSummationEnabled', 'Humidity', 'PhotonEnergy', 'Wavelength',
+    ],
     'tangovimba': [
         'Width', 'WidthMax', 'TriggerSource', 'PixelFormat', 'OffsetY',
         'OffsetX', 'HeightMax', 'Height', 'GainRaw', 'ExposureTimeAbs',
