@@ -111,7 +111,7 @@ class NXSCreateOnlineCPFS2Test(
                      'ts_myeigerdectris_flatfieldenabled',
                      'ts_myeigerdectris_frametime',
                      'ts_myeigerdectris_humidity',
-                     'ts_myeigerdectris_nbimages',
+                     'ts_myeigerdectris_nbimages_cb',
                      'ts_myeigerdectris_nbtriggers',
                      'ts_myeigerdectris_photonenergy',
                      'ts_myeigerdectris_ratecorrectionenabled',
@@ -152,11 +152,11 @@ class NXSCreateOnlineCPFS2Test(
                      '        <field units="s" type="NX_FLOAT64" '
                      'name="count_time">'
                      '$datasources.myeigerdectris_counttime'
-                     '<strategy mode="STEP"/>\n'
+                     '<strategy mode="FINAL"/>\n'
                      '        </field>\n'
                      '        <field units="s" type="NX_FLOAT64" '
                      'name="frame_time">$datasources.myeigerdectris_frametime'
-                     '<strategy mode="STEP"/>\n'
+                     '<strategy mode="FINAL"/>\n'
                      '        </field>\n'
                      '        <field units="eV" type="NX_FLOAT64" '
                      'name="threshold_energy">'
@@ -176,7 +176,7 @@ class NXSCreateOnlineCPFS2Test(
                      '        <group type="NXcollection" name="collection">\n'
                      '          <field type="NX_UINT64" name="nb_images">\n'
                      '            <strategy mode="STEP"/>'
-                     '$datasources.myeigerdectris_nbimages</field>\n'
+                     '$datasources.myeigerdectris_nbimages_cb</field>\n'
                      '          <field type="NX_UINT64" name="nb_triggers">\n'
                      '            <strategy mode="FINAL"/>'
                      '$datasources.myeigerdectris_nbtriggers</field>\n'
@@ -238,7 +238,7 @@ class NXSCreateOnlineCPFS2Test(
                      '    <result name="result">\n'
                      'from nxstools.pyeval import common\n'
                      'common.blockitem_rm(commonblock, '
-                     '["myeigerdectris_stepindex""])\n'
+                     '["myeigerdectris_stepindex"])\n'
                      'ds.result = ds.myeigerdectris_description\n'
                      '</result>\n'
                      '  $datasources.myeigerdectris_description\n'
@@ -299,15 +299,15 @@ class NXSCreateOnlineCPFS2Test(
                      '    <record name="Humidity"/>\n'
                      '  </datasource>\n'
                      '</definition>\n',
-                     '<?xml version=\'1.0\' encoding=\'utf8\'?>\n'
+                     '<?xml version=\'1.0\'?>\n'
                      '<definition>\n'
-                     '  <datasource type="TANGO"'
-                     ' name="myeigerdectris_nbimages"'
+                     '  <datasource type="PYEVAL"'
+                     ' name="myeigerdectris_nbimages_cb"'
                      '>\n'
-                     '    <device name="p09/eigerdectris/exp.01" '
-                     'member="attribute" hostname="haso000" '
-                     'port="10000" group="myeigerdectris_"/>\n'
-                     '    <record name="NbImages"/>\n'
+                     '    <result name="result">\n'
+                     'ds.result = ds.myeigerdectris_nbimages\n'
+                     '    </result>\n'
+                     '    $datasources.myeigerdectris_nbimages\n'
                      '  </datasource>\n'
                      '</definition>\n',
                      '<?xml version=\'1.0\' encoding=\'utf8\'?>\n'
