@@ -22,12 +22,11 @@
 import unittest
 # import os
 import sys
-# import random
-# import struct
-# import binascii
-# import time
-# import threading
-import PyTango
+try:
+    import tango
+except Exception:
+    import PyTango as tango
+
 from os.path import expanduser
 # import json
 # from nxstools import nxscreate
@@ -83,10 +82,10 @@ class NXSCreatePoolDSDBRTest(
     # closes opens config server
     # \param xmlc XMLConfigurator instance
     def closeConfig2(self):
-        self.assertEqual(self._proxy2.state(), PyTango.DevState.OPEN)
+        self.assertEqual(self._proxy2.state(), tango.DevState.OPEN)
 
         self._proxy2.Close()
-        self.assertEqual(self._proxy2.state(), PyTango.DevState.ON)
+        self.assertEqual(self._proxy2.state(), tango.DevState.ON)
 
     # test starter
     # \brief Common set up
