@@ -313,6 +313,7 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                      "parametercopymap", "pinhole",
                      "pointdet", "qbpm", "sampledescription",
                      "sampledescriptiontext", "samplehkl", "secop",
+                     "secoplinks",
                      "singlesecop", "slit", "source", "starttime",
                      "tango", "undulator"])
                 self.assertEqual(lines[-1], "")
@@ -338,7 +339,7 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                  "parametercopymap", "pinhole",
                  "pointdet", "qbpm", "sampledescription",
                  "sampledescriptiontext", "samplehkl",
-                 "secop", "singlesecop", "slit",
+                 "secop", "secoplinks", "singlesecop", "slit",
                  "source", "starttime", "tango", "undulator"]
         args = [
                 ('nxscreate stdcomp %s -t ' % self.flags).split(),
@@ -930,6 +931,8 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                      '    </group>\n'
                      '    <field name="program_name" '
                      'scan_command="$var.scan_title" scan_id="$var.scan_id" '
+                     'npoints="$var.npoints" count_time="$var.count_time" '
+                     'beamtime_id="$var.beamtime_id" '
                      'measurement_group="$var.measurement_group" '
                      'measurement_group_channels="$var.mgchannels" '
                      'nexus_components="$var.nexus_components" '
@@ -1106,6 +1109,8 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                      '    </group>\n'
                      '    <field name="program_name" '
                      'scan_command="$var.scan_title" scan_id="$var.scan_id" '
+                     'npoints="$var.npoints" count_time="$var.count_time" '
+                     'beamtime_id="$var.beamtime_id" '
                      'measurement_group="$var.measurement_group" '
                      'measurement_group_channels="$var.mgchannels" '
                      'nexus_components="$var.nexus_components" '
@@ -1575,7 +1580,8 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
             "common4",
         ]
 
-        if __name__ == 'test.NXSCreateStdCompFSTest':
+        if __name__ in ['test.NXSCreateStdCompFSTest',
+                        'test.NXSCreateStdCompFS_test']:
             args = [
                 ('nxscreate stdcomp %s -p test.nxsextrasp00 -c cptest -t '
                  % self.flags).split(),
